package opartgui;
import java.awt.event.*;
import javax.swing.event.*;
import java.io.*;
import java.awt.geom.*;
import javax.swing.*;
import java.awt.*;
public class PanelLoader{
        
        private CataractOptionPane cataractOptionPane = new CataractOptionPane();
        private BrittaniaOptionPane brittaniaOptionPane = new BrittaniaOptionPane();
        private ArrestOptionPane arrestOptionPane = new ArrestOptionPane();
        private Ellipse2OptionPane ellipse2OptionPane = new Ellipse2OptionPane();
        private EllipseOptionPane ellipseOptionPane = new EllipseOptionPane();
        private Rect2OptionPane rect2OptionPane = new Rect2OptionPane();
        private RectOptionPane rectOptionPane = new RectOptionPane();
        private PauseOptionPane pauseOptionPane = new PauseOptionPane();
        private OrientOptionPane orientOptionPane = new OrientOptionPane();
        private FallOptionPane fallOptionPane = new FallOptionPane();
        private CrestOptionPane crestOptionPane = new CrestOptionPane();
        private AccidentOptionPane accidentOptionPane = new AccidentOptionPane();


        public PanelLoader(){

        }

        public JScrollPane cataractPanelLoad(){
               return (cataractOptionPane.cataractPaneLoad());
        }

        public JScrollPane accidentPanelLoad(){
               return (accidentOptionPane.accidentPaneLoad());
        }

        public JScrollPane crestPanelLoad(){
               return (crestOptionPane.crestPaneLoad());
        }

        public JScrollPane fallPanelLoad(){
               return (fallOptionPane.fallPaneLoad());
        }

        public JScrollPane orientPanelLoad(){
               return (orientOptionPane.orientPaneLoad());
        }

        public JScrollPane pausePanelLoad(){
               return (pauseOptionPane.pausePaneLoad());
        }

        public JScrollPane ellipsePanelLoad(){
               return (ellipseOptionPane.ellipsePaneLoad());
        }

        public JScrollPane ellipse2PanelLoad(){
               return (ellipse2OptionPane.ellipse2PaneLoad());
        }

        public JScrollPane rectPanelLoad(){
               return (rectOptionPane.rectPaneLoad());
        }

        public JScrollPane rect2PanelLoad(){
               return (rect2OptionPane.rect2PaneLoad());
        }

        public JScrollPane arrestPanelLoad(){
               return (arrestOptionPane.arrestPaneLoad());
        }

        public JScrollPane brittaniaPanelLoad(){
               return (brittaniaOptionPane.brittaniaPaneLoad());
        }

}

